@@ -1,10 +1,10 @@
-# @(#)$Id: DataClass.pm 336 2012-03-20 18:19:58Z pjf $
+# @(#)$Id: DataClass.pm 338 2012-03-21 22:41:29Z pjf $
 
 package File::DataClass;
 
 use strict;
-use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 336 $ =~ /\d+/gmx );
+use namespace::clean -except => 'meta';
+use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 338 $ =~ /\d+/gmx );
 
 use Moose;
 use MooseX::ClassAttribute;
@@ -46,7 +46,7 @@ File::DataClass - Structured data file IO with OO paradigm
 
 =head1 Version
 
-This document describes File::DataClass version 0.7.$Revision: 336 $
+This document describes File::DataClass version 0.7.$Revision: 338 $
 
 =head1 Synopsis
 
@@ -147,3 +147,4 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE
 # mode: perl
 # tab-width: 3
 # End:
+
